@@ -9,11 +9,13 @@ from attrs import define
 from countergen.augmentation.simple_augmenter import SimpleAugmenter
 from countergen.config import MODULE_PATH
 from countergen.tools.utils import FromAndToJson, all_same, maybe_tqdm
-from countergen.types import AugmentedSample, Augmenter, Category, Input, Outputs, Paraphraser, Variation
+from countergen.types import AugmentedSample, Augmenter, Category, Input, Outputs, Paraphraser, Sample, Variation
 
 DEFAULT_DS_PATHS: Mapping[str, str] = {
-    "doublebind-heilman": f"{MODULE_PATH}/data/datasets/doublebind-heilman.jsonl",
-    "doublebind": f"{MODULE_PATH}/data/datasets/doublebind.jsonl",
+    "doublebind-negative-1token": f"{MODULE_PATH}/data/datasets/doublebind-negative-1token.jsonl",
+    "doublebind-negative": f"{MODULE_PATH}/data/datasets/doublebind-negative.jsonl",
+    "doublebind-positive-1token": f"{MODULE_PATH}/data/datasets/doublebind-positive-1token.jsonl",
+    "doublebind-positive": f"{MODULE_PATH}/data/datasets/doublebind-positive.jsonl",
     "male-stereotypes": f"{MODULE_PATH}/data/datasets/male-stereotypes.jsonl",
     "female-stereotypes": f"{MODULE_PATH}/data/datasets/female-stereotypes.jsonl",
     "tiny-test": f"{MODULE_PATH}/data/datasets/tiny-test.jsonl",
@@ -22,8 +24,8 @@ DEFAULT_DS_PATHS: Mapping[str, str] = {
 }
 
 DEFAULT_AUGMENTED_DS_PATHS: Mapping[str, str] = {
-    "doublebind-heilman-paraphrased": f"{MODULE_PATH}/data/augdatasets/doublebind-heilman-paraphrased.jsonl",
-    "doublebind": f"{MODULE_PATH}/data/augdatasets/doublebind.jsonl",
+    "doublebind-positive-paraphrased": f"{MODULE_PATH}/data/augdatasets/doublebind-positive-paraphrased.jsonl",
+    "doublebind-negative-paraphrased": f"{MODULE_PATH}/data/augdatasets/doublebind-negative-paraphrased.jsonl",
     "tiny-test-aug-gender": f"{MODULE_PATH}/data/augdatasets/tiny-test.jsonl",
     "twitter-sentiment-aug-gender": f"{MODULE_PATH}/data/augdatasets/twitter-sentiment.jsonl",
     "hate-aug-muslim": f"{MODULE_PATH}/data/augdatasets/hate-test-muslims.jsonl",
@@ -31,13 +33,7 @@ DEFAULT_AUGMENTED_DS_PATHS: Mapping[str, str] = {
 
 
 @define
-class Sample(FromAndToJson):
-    input: Input
-    outputs: Outputs = []
-
-
-@define
-class SampleWithVariations(Sample, AugmentedSample):
+class SimpleAugmentedSample(Sample, AugmentedSample):
     """AugmentedSample which explicitly stores all variations."""
 
     variations: List[Variation] = []
@@ -49,8 +45,8 @@ class SampleWithVariations(Sample, AugmentedSample):
         return self.outputs
 
     @classmethod
-    def from_sample(cls, s: Sample, variations: List[Variation] = []) -> "SampleWithVariations":
-        return SampleWithVariations(s.input, s.outputs, variations)
+    def from_sample(cls, s: Sample, variations: List[Variation] = []) -> "SimpleAugmentedSample":
+        return SimpleAugmentedSample(s.input, s.outputs, variations)
 
 
 @define
@@ -58,7 +54,7 @@ class Dataset:
     samples: List[Sample]
 
     @classmethod
-    def from_default(cls, name: str = "doublebind") -> "Dataset":
+    def from_default(cls, name: str) -> "Dataset":
         """Load one of the defaults datasets from "DEFAULT_DS_PATHS"."""
         if name not in DEFAULT_DS_PATHS:
             raise ValueError(
@@ -86,10 +82,10 @@ class Dataset:
 
 @define
 class AugmentedDataset:
-    samples: List[SampleWithVariations]
+    samples: List[SimpleAugmentedSample]
 
     @classmethod
-    def from_default(cls, name: str = "doublebind-heilman") -> "AugmentedDataset":
+    def from_default(cls, name: str) -> "AugmentedDataset":
         """Load one of the defaults datasets from "DEFAULT_AUGMENTED_DS_PATHS"."""
         if name not in DEFAULT_AUGMENTED_DS_PATHS:
             raise ValueError(
@@ -103,7 +99,7 @@ class AugmentedDataset:
             data = [json.loads(line) for line in f]
             samples = []
             for d in data:
-                samples.append(SampleWithVariations.from_json_dict(d))
+                samples.append(SimpleAugmentedSample.from_json_dict(d))
         return AugmentedDataset(samples)
 
     def save_to_jsonl(self, path: str):
@@ -148,7 +144,6 @@ def generate_all_variations(augmenters: Iterable[Augmenter], ds: Dataset) -> Aug
 
     augmented_samples = []
 
-    print(countergen.config.verbose)
     for sample in maybe_tqdm(ds.samples, countergen.config.verbose >= 2):
         variations = [Variation(sample.input, ())]
         for augmenter in augmenters:
@@ -156,5 +151,5 @@ def generate_all_variations(augmenters: Iterable[Augmenter], ds: Dataset) -> Aug
             for v in variations:
                 new_variations += generate_variations(v, augmenter)
             variations = new_variations
-        augmented_samples.append(SampleWithVariations.from_sample(sample, variations))
+        augmented_samples.append(SimpleAugmentedSample.from_sample(sample, variations))
     return AugmentedDataset(augmented_samples)
