@@ -5,13 +5,13 @@ import numpy as np
 from attrs import define
 
 from countergen.tools.plot_utils import plot_mutli_bars
-from countergen.types import AugmentedSample, Category, Input, Performance, Results, StatsAggregator, Outputs
+from countergen.types import AugmentedSample, Category, Input, Performance, Results, Aggregator, Outputs
 from countergen.tools.math_utils import geometric_mean, mean
 from countergen.tools.utils import FromAndToJson
 
 
 @define
-class AveragePerformancePerCategory(StatsAggregator):
+class AveragePerformancePerCategory(Aggregator):
     """Compute the average performance for each category."""
 
     use_geometric_mean: bool = False
@@ -66,7 +66,7 @@ class Stats(FromAndToJson):
 
 
 @define
-class PerformanceStatsPerCategory(StatsAggregator):
+class PerformanceStatsPerCategory(Aggregator):
     """Compute performance mean and the 2 sigma uncertainty over mean for each category."""
 
     def __call__(self, performances: Results) -> Mapping[Category, Stats]:
@@ -105,10 +105,16 @@ class PerformanceStatsPerCategory(StatsAggregator):
 
 
 @define
-class DifferenceStats(StatsAggregator):
+class DifferenceStats(Aggregator):
+    """Compute performance mean and the 2 sigma uncertainty (relative) difference of the performance in each samples.
+
+    Return a positive mean if category1 has higher performance that category2, and a negative one otherwise.
+
+    If a sample has mutliple variations of the same category, compute the mean performance of the category."""
+
     category1: Category
     category2: Category
-    relative_difference: bool = False  #: If True, return how much cat2er the cat2 category is on average
+    relative_difference: bool = True
 
     def __call__(self, performances: Results) -> Stats:
         differences = []
@@ -139,13 +145,13 @@ OutlierData = Tuple[Input, Outputs, Tuple[Category, ...], Performance]
 
 
 @define
-class OutliersAggregator(StatsAggregator):
+class OutliersAggregator(Aggregator):
     """Return the variations with the biggest (relative) performance gap."""
 
     aug_samples: Iterable[AugmentedSample]  #: Contains data about the inputs used
     top_k: int = 5
     use_relative_performance: bool = True
-    espilon: float = 1e-10
+    epsilon: float = 1e-10
 
     def __call__(self, performances: Results) -> List[Tuple[OutlierData, OutlierData]]:
         possibles_outliers: List[Tuple[OutlierData, OutlierData, float]] = []
@@ -184,4 +190,4 @@ class OutliersAggregator(StatsAggregator):
         if small_perf < 0:
             raise ValueError("Can't use relative performance when performance is negative.")
 
-        return delta / (big_perf + self.espilon) if self.use_relative_performance else delta
+        return delta / (big_perf + self.epsilon) if self.use_relative_performance else delta
