@@ -19,10 +19,14 @@ from countergen.tools.utils import FromAndToJson
 Input = str  # The input to an NLP mode
 Outputs = List[str]  # The different acceptable outputs of the NLP, string label or number, but in string format
 
-Performance = float  # usually between zero & one (one is better)
 
-# Callable that returns the performance of a model given an input and expected outputs.
-ModelEvaluator = Callable[[Input, Outputs], Performance]
+@define
+class Sample(FromAndToJson):
+    """An input associated with its possible outputs."""
+
+    input: Input
+    outputs: Outputs = []
+
 
 Category = str  # The different kinds of data produced by augmenters.
 
@@ -88,13 +92,18 @@ class AugmentedSample(metaclass=abc.ABCMeta):
         ...
 
 
+Performance = float  # usually between zero & one (one is better)
+
+# Callable that returns the performance of a model given an input and expected outputs.
+ModelEvaluator = Callable[[Input, Outputs], Performance]
+
 SampleResults = Iterable[Tuple[Performance, Tuple[Category, ...]]]
 Results = Iterable[SampleResults]
 
 Aggregate = TypeVar("Aggregate")
 
 
-class StatsAggregator(Generic[Aggregate], metaclass=abc.ABCMeta):
+class Aggregator(Generic[Aggregate], metaclass=abc.ABCMeta):
     """Objects that can aggregate, and optionally save, load and display the performances of models.
 
     The aggregate can be of any type."""
